![](https://raw.githubusercontent.com/PttCodingMan/PyPtt/master/logo/facebook_cover_photo_2.png)
# PyPtt
[![Package Version](https://img.shields.io/pypi/v/PyPtt.svg)](https://pypi.python.org/pypi/PyPtt)
![PyPI - Downloads](https://img.shields.io/pypi/dm/PyPtt)
[![test](https://github.com/PyPtt/PyPtt/actions/workflows/test.yml/badge.svg)](https://github.com/PyPtt/PyPtt/actions/workflows/test.yml)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/PyPtt)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)

#### PyPtt (PTT Library) 是一套 Pure Python PTT API 是目前支援最完整的 PTT API。具備大部分常用功能，無論推文、發文、取得文章、取得信件、寄信、發 P 幣、丟水球，你都可以在這裡找到完整的使用範例
#### 使用帳號登入，支援使用登入之後才可以使用的功能，例如：推文、發文、寄信、發 P 幣等等
#### 本專案意旨在提供 PTT 自動化機器人函式庫，無意違反任何 PTT 站方規範。如有牴觸，請馬上告知。
####
#### Pypi: https://pypi.org/project/PyPtt/
<img src="https://raw.githubusercontent.com/PyPtt/PyPtt/master/docs/_static/login_1.0.gif" width="560">

## 安裝
```bash
pip install PyPtt
```

## 回報問題
#### 請參考 [常見問題](https://pyptt.cc/faq.html) 章節

## 加入 PyPtt 社群
#### 你可以在 Telegram 上找到 PyPtt 社群 [![chatroom icon](https://patrolavia.github.io/telegram-badge/chat.png)](https://t.me/PyPtt)

## 贊助
#### 如果這個專案對你有幫助，贊助我一杯咖啡吧!!
####
#### [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)

## 贊助清單

#### leftc
